@@ -19,6 +19,14 @@ class FileHandler:
                 return _content
         except FileNotFoundError as err:
             return f'{self._filename} is not found, please enter the correct file!'
+    
+    def get_line_count(self):
+        """Returns number of lines in file"""
+        try:
+            num_lines = sum(1 for _ in open(self._filename))
+            return num_lines
+        except FileNotFoundError as err:
+            return f'{self._filename} is not found, please enter the correct file!'
 
     def change_file_content(self, new_content):
         """Changes whole file content"""
@@ -52,21 +60,24 @@ class FileHandler:
             return "This is a HTML file"
         elif self._filename.endswith('.css'):
             return "This is a CSS file"
+        elif self._filename.endswith('.rb'):
+            return "This is a Ruby file"
+        elif self._filename.endswith('.swift'):
+            return "This is a Swift file"
         else:
             return "Unknown file/extension. Please Report The Developers [ https://github.com/ProjectsWithPython/FileHandling/issues ]"
-
-
-
-
         
-
-            
-    
-
+    def change_file_extension(self, current_extension, new_extension):
+        try:
+            os.name(self._filename, self._filename.replace(rf'[{current_extension}]', f'{new_extension}'))
+            return 'Done!'
+        except:
+            return f"Please Report The Developers [ https://github.com/ProjectsWithPython/FileHandling/issues ]"
 
 
 
 def change_file_name(path, new_name):
+    """Changes file name"""
     os.rename(path, new_name)
 
 
@@ -79,6 +90,7 @@ def delete(file):
 
 
 def create_file(file):
+    """Creates a file"""
     if os.path.exists(file):
         return False
     else:
@@ -87,10 +99,27 @@ def create_file(file):
         return "Created File"
 
 
-
 def list_item_in_dir(path) -> list:
+    """Gives a list of all items in the folder"""
     if os.path.exists(path):
         return os.listdir(path)
     else:
         raise FileNotFoundError('Folder Not Found!')
 
+def delete_all_item_in_dict(path):
+    """Deletes all items in the folder"""
+    em = []
+    if os.path.exists(path):
+        for i in os.listdir(path):
+            os.remove(i)
+            em.append(i)
+        return em
+    else:
+        raise FileNotFoundError('Folder not found or wrong path.')
+
+def is_pythonfile(file):
+    """Returns True if file extension is py and if not then false."""
+    if file.endswith('py'):
+        return True
+    else: 
+        return False
